<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2019 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

namespace Akeeba\TicketSystem\Admin\CustomField;

use Akeeba\TicketSystem\Admin\Helper\Format;
use Akeeba\TicketSystem\Admin\Model\CustomFields;
use JFactory;
use JText;

defined('_JEXEC') or die();

/**
 * A date input field
 *
 * @author Nicholas K. Dionysopoulos
 */
class Date extends Base
{
	public function getField($item, $cache, $userparams)
	{
		// Get the current value
		if (is_array($cache) && array_key_exists($item->slug, $cache['params']))
		{
			$current = $cache['params'][ $item->slug ];
		}
		else
		{
			if (!is_object($userparams->params))
			{
				$current = $item->default;
			}
			else
			{
				$slug    = $item->slug;
				$current = property_exists($userparams->params, $item->slug) ? $userparams->params->$slug : $item->default;
			}
		}

		// Is this a required field?
		$required = $item->allow_empty ? '' : '* ';

		// Set up field's HTML content
		$html = \JHTML::_('calendar', $current, 'params[' . $item->slug . ']', $item->slug);

		// Setup the field
		$field = array(
			'id'          => $item->slug,
			'label'       => $required . JText::_($item->title),
			'elementHTML' => $html,
			'isValid'     => $required ? (!empty($current) && $current != '0000-00-00 00:00:00') : true
		);

		if ($item->invalid_label)
		{
			$field['invalidLabel'] = JText::_($item->invalid_label);
		}
		if ($item->valid_label)
		{
			$field['validLabel'] = JText::_($item->valid_label);
		}

		return $field;
	}

	/**
	 * Validate a date field
	 *
	 * @param   CustomFields  $item    The custom field to validate
	 * @param   array         $custom  The custom fields' values array
	 *
	 * @return  int  1 if the field is valid, 0 otherwise
	 */
	public function validate($item, &$custom)
	{
		if (!is_array($custom) || !array_key_exists($item->slug, $custom))
		{
			$custom[ $item->slug ] = '';
		}

		$valid = true;

		if (!$item->allow_empty)
		{
			$valid = !empty($custom[ $item->slug ]);

			if ($valid)
			{
				$valid = $custom[ $item->slug ] != '0000-00-00 00:00:00';
			}
		}

		return $valid ? 1 : 0;
	}

	public function getDisplay(CustomFields $item, $value)
	{
		return Format::date($value);
	}
}
