<?php
/**
 * @package   ats
 * @copyright Copyright (c)2011-2019 Nicholas K. Dionysopoulos / Akeeba Ltd
 * @license   GNU GPL v3 or later
 */

/** @var $this FOF30\View\DataView\Html */

use Akeeba\TicketSystem\Admin\Helper\Html;
use FOF30\Utils\FEFHelper\BrowseView;
use Akeeba\TicketSystem\Admin\Helper\Select;

defined('_JEXEC') or die;

?>
@jsLang('JLIB_HTML_PLEASE_MAKE_A_SELECTION_FROM_THE_LIST')
@js('media://com_ats/js/modal.js')
@js('media://com_ats/js/adm_tickets.js')

@extends('admin:com_ats/Common/browse')

@section('browse-filters')
    <div class="akeeba-filter-element akeeba-form-group">
        @searchfilter('ats_ticket_id', 'ats_ticket_id', 'JGRID_HEADING_ID')
    </div>

    <div class="akeeba-filter-element akeeba-form-group">
        @searchfilter('username', 'username', 'COM_ATS_TICKETS_HEADING_USER')
    </div>

    <div class="akeeba-filter-element akeeba-form-group">
        @searchfilter('ass_username', 'ass_username', 'COM_ATS_TICKETS_ASSIGNED_TO')
    </div>

    <div class="akeeba-filter-element akeeba-form-group">
        @searchfilter('title', 'title', 'COM_ATS_TICKETS_HEADING_TITLE')
    </div>

    <div class="akeeba-filter-element akeeba-form-group">
        {{ Select::ticketstatuses($this->getModel()->getState('status'), 'status', ['onchange' => 'document.adminForm.submit();'], 'filter_status') }}
    </div>

    <div class="akeeba-filter-element akeeba-form-group">
        {{ Select::publicstate($this->getModel()->getState('public'), 'public', ['onchange' => 'document.adminForm.submit();']) }}
    </div>

    <div class="akeeba-filter-element akeeba-form-group">
        <select name="catid" class="input-medium" onchange="this.form.submit()">
            <option value="">@lang('JOPTION_SELECT_CATEGORY')</option>
            @jhtml('select.options', JHtml::_('category.options', 'com_ats'), 'value', 'text', $this->getModel()->getState('catid',''))
        </select>
    </div>

    <div class="akeeba-filter-element akeeba-form-group">
        {{ BrowseView::publishedFilter('enabled', 'JENABLED') }}
    </div>
@stop

@section('browse-table-header')
    <tr>
        <th width="20px">
            @jhtml('FEFHelper.browse.checkall')
        </th>
        <th>
            @sortgrid('ats_ticket_id', 'JGRID_HEADING_ID')
        </th>
        <th>
            @sortgrid('created_by', 'COM_ATS_TICKETS_HEADING_USER')
        </th>
        <th>
            @sortgrid('created_on', 'COM_ATS_TICKETS_HEADING_CREATED')
        </th>
        <th>
            @sortgrid('modified_on', 'COM_ATS_TICKETS_HEADING_MODIFIED')
        </th>
        <th>
            @sortgrid('title', 'COM_ATS_COMMON_TITLE')
        </th>
        @if(ATS_PRO)
            <th>
                @sortgrid('timespent', 'COM_ATS_TICKETS_HEADING_TIMESPENT')
            </th>
        @endif
        <th width="5%">
            @sortgrid('enabled', 'JSTATUS')
        </th>
        <th width="10%">
            @sortgrid('status', 'COM_ATS_TICKETS_HEADING_STATUS')
        </th>
        <th width="5%">
            @sortgrid('public', 'COM_ATS_TICKETS_HEADING_PUBLIC')
        </th>
        <th width="10%">
            @sortgrid('catid', 'JCATEGORY')
        </th>
    </tr>
@stop

@section('browse-table-body-withrecords')
	<?php
	$i = 0;
	$user = $this->getContainer()->platform->getUser();
	$enabled = $user->authorise('core.edit.state', 'com_ats');
	/** @var \Akeeba\TicketSystem\Admin\Model\Tickets $item */
	?>
    @foreach($this->items as $item)
	<?php
	$item->cat_link = JRoute::_('index.php?option=com_categories&extension=com_ats&task=edit&type=other&cid[]=' . $item->catid);
	$canEdit = $user->authorise('core.edit', 'com_ats.category.' . $item->catid);
	$canChange = $user->authorise('core.edit.state', 'com_ats.category.' . $item->catid);
	$assigned_class = $item->assigned_to ? 'akeeba-label--teal' : 'akeeba-label--grey';
	$assigned_to = $item->assigned_to ? $item->assigned->name : JText::_('COM_ATS_TICKETS_UNASSIGNED');
	?>
    <tr>
        <td>
            @jhtml('FEFHelper.browse.id', ++$i, $item->getId())
        </td>
        <td>
            @include('admin:com_ats/Common/TicketPriority', ['item' => $item])

            {{ $item->ats_ticket_id }}
        </td>
        <td>
            @include('admin:com_ats/Common/ShowUser', ['item' => $item, 'field' => 'created_by', 'showLink' => false])
        </td>
        <td class="nowrap">
            @jhtml('date',$item->created_on, JText::_('DATE_FORMAT_LC4'))
        </td>
        <td class="nowrap">
            @if($item->modified_on == '0000-00-00 00:00:00')
            &mdash;
            @else
                @jhtml('date',$item->modified_on, JText::_('DATE_FORMAT_LC4'))
            @endif
        </td>
        <td>
			<?php
			$title = $this->escape($item->title);

			if ($canEdit)
			{
				$title = '<a href="' . JRoute::_('index.php?option=com_ats&view=Ticket&task=edit&id=' . (int) $item->ats_ticket_id) . '">' . $this->escape($item->title) . '</a>';
			}
			?>
            @if(ATS_PRO)
                <div class="assignto">
                    {{ \Akeeba\TicketSystem\Admin\Helper\Html::buildManagerdd(null, $assigned_to, $item->catid) }}
                    <input type="hidden" class="ticket_id" value="{{ $item->ats_ticket_id }}" />
                </div>
            @endif
            {{ $title }}
        </td>
        @if(ATS_PRO)
            <td class="nowrap">
                {{ $item->timespent > 0 ? sprintf('%.1f', $item->timespent) : '&mdash;' }}
            </td>
        @endif
        <td>
            @jhtml('FEFHelper.browse.published', $item->enabled, $i, '', $enabled)
        </td>
        <td class="center">
            <div class="ticketstatus">
                {{ Html::createStatusDropdown($item->status) }}
            </div>
        </td>
        <td class="center public">
            @jhtml('jgrid.published', $item->public, $i, 'public_', $canChange)
        </td>
        <td class="center">
            {{ is_object($item->joomla_category) ? $item->joomla_category->title : '' }}
        </td>
    </tr>
    @endforeach
@stop